@@ -78,7 +78,7 @@ class FacebookFanPlugin(CMSPluginBase):
             return context
         
         # get data
-        query = "posts?fields=picture,message&limit=100"
+        query = "posts?fields=full_picture,message&limit=100"
         req = requests.get(
             'https://graph.facebook.com/v2.8/%s/%s&access_token=%s' % (
             fanPageId, query, accessToken)
@@ -97,8 +97,8 @@ class FacebookFanPlugin(CMSPluginBase):
                 msg = mark_safe(data['message'].replace('\n', '<br />'))
             else:
                 continue
-            if 'picture' in data:
-                img = data['picture']
+            if 'full_picture' in data:
+                img = data['full_picture']
             if 'created_time' in data:
                 createdTime = data['created_time']
             if 'id' in data:
@@ -138,7 +138,7 @@ class FacebookPhotoPlugin(CMSPluginBase):
                           u'?tab=album&album_id=xxx'),
             })
             return context
-        query = "?fields=photos.limit(100){name,picture}"
+        query = "?fields=photos.limit(100){name,images}"
         req = requests.get(
             'https://graph.facebook.com/v2.8/%s/%s&access_token=%s' % (
             albumId, query, accessToken)
@@ -161,9 +161,12 @@ class FacebookPhotoPlugin(CMSPluginBase):
         for data in content:
             name = None
             url = None
-            if not 'picture' in data:
+            if not 'images' in data:
                 continue
-            url = data['picture']
+            for data2 in data['images']:
+                if 'source' in data2:
+                    url = data2['source']
+                    break
             if 'name' in data:
                 name = mark_safe(data['name'].replace('\n', '<br />'))
             photoList.append(Photo(name, url))
